**********************
Numba Module Reference
**********************

Contents:

.. toctree::
   :titlesonly:
   :maxdepth: 2

   modules/numba.rst
   modules/ast_constant_folding.rst
   modules/ast_translate.rst
   modules/ast_type_inference.rst
   modules/cfg.rst
   modules/closure.rst
   modules/decorators.rst
   modules/functions.rst
   modules/llvm_types.rst
   modules/minivect.rst
   modules/multiarray_api.rst
   modules/naming.rst
   modules/ndarray_helpers.rst
   modules/nodes.rst
   modules/pipeline.rst
   modules/pycc.rst
   modules/stdio_util.rst
   modules/symtab.rst
   modules/transforms.rst
   modules/translate.rst
   modules/utils.rst
   modules/visitors.rst
